
<nz-card class="status-card" *ngIf="item$ | async as item">
    <nz-descriptions nzBordered [nzColumn]="1">
        <nz-descriptions-item nzTitle="Added / Updated Events">
            {{ item.addedEvents }}
        </nz-descriptions-item>

        <nz-descriptions-item nzTitle="Updated Alarm Flags">
            {{ item.updatedAlarmFlags }}
        </nz-descriptions-item>

        <nz-descriptions-item nzTitle="Removed Events">
            {{ item.removedEvents }}
        </nz-descriptions-item>

        <nz-descriptions-item nzTitle="Last Activity">
            {{ item.lastActivity | date:'medium' }}
        </nz-descriptions-item>
    </nz-descriptions>
</nz-card>