
.filter-form {
    display: flex;
    flex-direction: column;
    gap: 16px;
}

.date-range-container {
    display: flex;
    flex-wrap: wrap;
    gap: 16px;
}

.date-picker-group {
    flex: 1 1 200px;
    display: flex;
    flex-direction: column;
    gap: 8px;
}

.filter-table {
    width: 100%;
}

nz-select,
nz-date-picker {
    width: 100% !important;
}

.modal-footer {
    display: flex;
    justify-content: space-between;
    gap: 8px;
}

.modal-footer-right {
    display: flex;
    gap: 8px;
}

@media screen and (max-width: 575px) {
    .date-range-container {
        gap: 8px;
    }
    
    .date-picker-group {
        flex: 1 1 100%;
    }
}