
.list-container {
    display: flex;
    flex-direction: column;
    gap: 16px;
}

.table-wrapper {
    width: 100%;
    overflow-x: auto;
}

.date-cell {
    display: flex;
    flex-direction: column;
    gap: 4px;
    
    @media (min-width: 768px) {
        flex-direction: row;
        gap: 8px;
    }
}

.date-time {
    white-space: nowrap;
}

.action-cell {
    display: flex;
    gap: 8px;
    align-items: center;
}

td {
    vertical-align: middle;
}

// Ensure table cells don't wrap unnecessarily
.ant-table-cell {
    white-space: normal;
    word-break: break-word;
}

@media screen and (max-width: 575px) {
    .list-container {
        gap: 8px;
    }
}