@import "@synerty/peek-plugin-base-js/src/styles/_variables";

:host {
    display: flex;
    flex-grow: 1;
    flex-shrink: 1;
    flex-basis: auto;
}

.ant-card {
    width: 100%;

    .ant-card-head-wrapper {
        .ant-card-extra {
            display: flex;
            gap: $general_padding_1;
        }
    }
}

nz-select {
    min-width: 110pt;
}

.display-options {
    display: flex;
    gap: $general_padding_2;
    align-items: center;
    padding: $general_padding_1;
}

.nested-table {
    margin: $general_padding_1;

    .ant-table-wrapper {
        width: 100%;
    }
}

nz-input-number {
    width: 100%;
}

[nz-input] {
    width: 100%;
}
