
.column-container {
    display: flex;
    flex-direction: column;
    gap: 16px;
}

.select-container {
    display: flex;
    flex-direction: column;
    gap: 8px;
}

nz-select {
    width: 100%;
}

.modal-footer {
    display: flex;
    justify-content: space-between;
    gap: 8px;
}

.modal-footer-right {
    display: flex;
    gap: 8px;
}

button {
    min-width: 80px;
}

.hint-text {
    color: rgba(0, 0, 0, 0.45);
    font-size: 12px;
    margin-top: 4px;
}

nz-alert {
    margin-bottom: 8px;
}

@media screen and (max-width: 575px) {
    .column-container {
        gap: 8px;
    }
    
    .modal-footer {
        flex-direction: column-reverse;
    }
    
    .modal-footer-right {
        width: 100%;
    }
    
    button {
        flex: 1;
    }
}