
/* Import common mixins and variables */
@import "@synerty/peek-plugin-base-js/src/styles/_mixins";
@import "@synerty/peek-plugin-base-js/src/styles/_variables";

.page-container {
    display: flex;
    flex-direction: column;
    gap: 16px;
    padding: 16px;
}

.content-section {
    display: flex;
    flex-direction: column;
    gap: 16px;
}

/* Ensure consistent switch height */
nz-switch {
    min-height: 32px;
    display: flex;
    align-items: center;
}

/* Note text styling */
.note-text {
    padding: 8px;
    background-color: #fafafa;
    border-radius: 4px;
    color: rgba(0, 0, 0, 0.65);
}

/* Responsive adjustments */
@media screen and (max-width: 575px) {
    .page-container {
        gap: 8px;
        padding: 8px;
    }
    
    [nz-button],
    nz-switch {
        margin-bottom: 8px;
    }
}